@@ -105,24 +105,29 @@ struct ata_drive_s {
 };
 
 static const uint8_t identify[128] = {
+    // 0x00
     0x40, 0x00, 0x00, 0x01, 0x00, 0x00, 0x04, 0x00,
     0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00,
     0x00, 0x00, 0x00, 0x00, 0x30, 0x32, 0x31, 0x31,
     0x38, 0x30, 0x30, 0x32, 0x20, 0x20, 0x20, 0x20,
 
+    // 0x20
     0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20,
     0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x36,
     0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x49, 0x56,
     0x45, 0x43, 0x48, 0x2d, 0x44, 0x44, 0x20, 0x20,
 
+    // 0x40
     0x20, 0x20, 0x41, 0x4b, 0x54, 0x4a, 0x52, 0x41,
     0x5a, 0x20, 0x4f, 0x53, 0x54, 0x4c, 0x28, 0x20,
     0x4f, 0x53, 0x49, 0x43, 0x53, 0x2f, 0x4e, 0x49,
     0x55, 0x47, 0x41, 0x4c, 0x29, 0x52, 0x01, 0x00,
 
+    // 0x60
     0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00,
     0x00, 0x00, 0x01, 0x00, 0x00, 0x01, 0x04, 0x00,
     0x10, 0x00, 0x00, 0x40, 0x00, 0x00, 0x01, 0x01,
+    // 0x78 (120)
     0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
 };
 
@@ -1277,7 +1282,12 @@ void ata_image_attach(ata_drive_t *drv, char *filename, ata_drive_type_t type, a
             drv->geometry.heads = identify[6];
             drv->geometry.sectors = identify[12];
             drv->geometry.size = drv->geometry.cylinders * drv->geometry.heads * drv->geometry.sectors;
-            if ((identify[99] & 0x02) && (identify[120] || identify[121] || identify[122] || identify[123])) {
+            if ((identify[99] & 0x02) &&
+                /* 0x78 (120): 0x00, 0x40, 0x00, 0x00 */
+                ((identify[120] != /* DISABLES CODE */ (0) ) ||
+                 (identify[121] != 0) ||
+                 (identify[122] != 0) ||
+                 (identify[123] != 0))) {
                 drv->geometry.size = identify[120];
                 drv->geometry.size |= identify[121] << 8;
                 drv->geometry.size |= identify[122] << 16;
